@@ -75,6 +75,22 @@ void		saturation_value_changed_cb			(GtkRange *range,
 
 void 	        reset_color_clicked_cb 			        (GtkButton *button, 
 								 ParoleConfDialog *self);
+								 
+void		replace_playlist_toggled_cb			(GtkToggleButton *widget,
+								 ParoleConfDialog *self);
+								 
+void		remove_duplicated_toggled_cb			(GtkToggleButton *widget,
+								 ParoleConfDialog *self);
+
+void		start_playing_opened_toggled_cb			(GtkToggleButton *widget,
+								 ParoleConfDialog *self);
+
+void		remember_playlist_toggled_cb			(GtkToggleButton *widget,
+								 ParoleConfDialog *self);
+								 
+void		multimedia_keys_toggled_cb			(GtkToggleButton *widget,
+								 ParoleConfDialog *self);
+								
 /*
  * End of GtkBuilder callbacks
  */
@@ -108,13 +124,47 @@ parole_conf_dialog_destroy (GtkWidget *widget, ParoleConfDialog *self)
     g_object_unref (self);
 }
 
+void replace_playlist_toggled_cb (GtkToggleButton *widget, ParoleConfDialog *self)
+{
+    g_object_set (G_OBJECT (self->priv->conf),
+		  "replace-playlist", gtk_toggle_button_get_active (widget),
+		  NULL);
+}
+								 
+void remove_duplicated_toggled_cb (GtkToggleButton *widget, ParoleConfDialog *self)
+{
+    g_object_set (G_OBJECT (self->priv->conf),
+		  "remove-duplicated", gtk_toggle_button_get_active (widget),
+		  NULL);
+}
+
+void start_playing_opened_toggled_cb (GtkToggleButton *widget, ParoleConfDialog *self)
+{
+    g_object_set (G_OBJECT (self->priv->conf),
+		  "play-opened-files", gtk_toggle_button_get_active (widget),
+		  NULL);
+}
+
+void remember_playlist_toggled_cb (GtkToggleButton *widget, ParoleConfDialog *self)
+{
+    g_object_set (G_OBJECT (self->priv->conf),
+		  "remember-playlist", gtk_toggle_button_get_active (widget),
+		  NULL);
+}
+
+void multimedia_keys_toggled_cb (GtkToggleButton *widget, ParoleConfDialog *self)
+{
+    g_object_set (G_OBJECT (self->priv->conf),
+		  "multimedia-keys", gtk_toggle_button_get_active (widget),
+		  NULL);
+}
+
 void reset_color_clicked_cb (GtkButton *button, ParoleConfDialog *self)
 {
     gtk_range_set_value (GTK_RANGE (self->priv->brightness), 0);
     gtk_range_set_value (GTK_RANGE (self->priv->contrast), 0);
     gtk_range_set_value (GTK_RANGE (self->priv->hue), 0);
     gtk_range_set_value (GTK_RANGE (self->priv->saturation), 0);
-    
 }
 
 void parole_conf_dialog_response_cb (GtkDialog *dialog, gint response_id, ParoleConfDialog *self)
@@ -223,9 +273,6 @@ void parole_conf_dialog_enable_subtitle_changed_cb (GtkToggleButton *widget, Par
     g_object_set (G_OBJECT (self->priv->conf),
 		  "enable-subtitle", active,
 		  NULL);
-    
-    gtk_widget_set_sensitive (self->priv->font_button, active);
-    
 }
 
 static void
@@ -301,6 +348,65 @@ parole_conf_dialog_set_default_vis_plugin (GtkTreeModel *model, GtkTreePath *pat
     return ret;
 }
 
+static void
+parole_conf_dialog_set_defaults_playlist (ParoleConfDialog  *self, GtkBuilder *builder)
+{
+    GtkWidget *widget;
+    gboolean option;
+    
+    /**
+     * Replace playlist with opened files.
+     **/
+    widget = GTK_WIDGET (gtk_builder_get_object (builder, "replace-playlist"));
+    
+    g_object_get (G_OBJECT (self->priv->conf),
+		  "replace-playlist", &option,
+		  NULL);
+		  
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), option);
+    
+     /**
+     * Start playing opened files
+     **/
+    widget = GTK_WIDGET (gtk_builder_get_object (builder, "start-playing-opened"));
+    
+    g_object_get (G_OBJECT (self->priv->conf),
+		  "play-opened-files", &option,
+		  NULL);
+		  
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), option);
+    
+     /**
+     * Remove duplicated playlist entries
+     **/
+    widget = GTK_WIDGET (gtk_builder_get_object (builder, "remove-duplicated"));
+    
+    g_object_get (G_OBJECT (self->priv->conf),
+		  "remove-duplicated", &option,
+		  NULL);
+		  
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), option);
+}
+
+static void
+parole_conf_dialog_set_defaults_general (ParoleConfDialog *self, GtkBuilder *builder)
+{
+    GtkWidget *widget;
+    gboolean option;
+    
+     /**
+     * Replace playlist with opened files.
+     **/
+    widget = GTK_WIDGET (gtk_builder_get_object (builder, "multimedia-keys"));
+    
+    g_object_get (G_OBJECT (self->priv->conf),
+		  "multimedia-keys", &option,
+		  NULL);
+		  
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), option);
+    
+}
+
 static void
 parole_conf_dialog_set_defaults (ParoleConfDialog *self)
 {
@@ -372,6 +478,8 @@ void parole_conf_dialog_open (ParoleConfDialog *self, GtkWidget *parent)
     self->priv->vis_combox = combox;
 
     parole_conf_dialog_set_defaults (self);
+    parole_conf_dialog_set_defaults_general (self, builder);
+    parole_conf_dialog_set_defaults_playlist (self, builder);
     
     g_object_get (G_OBJECT (self->priv->conf),
 		  "reset-saver", &reset_saver,
@@ -423,3 +531,4 @@ void parole_conf_dialog_open (ParoleConfDialog *self, GtkWidget *parent)
     
     gtk_widget_show (dialog);
 }
+
