@@ -68,9 +68,11 @@ enum
     PROP_MINIMIZED,
     PROP_MULTIMEDIA_KEYS,
     /*Playlist*/
+    PROP_SHOWHIDE_PLAYLIST,
     PROP_REPLACE_PLAYLIST,
     PROP_SCAN_FOLDER_RECURSIVELY,
     PROP_START_PLAYING_OPENED_FILES,
+    PROP_REMEMBER_PLAYLIST,
     PROP_REMOVE_DUPLICATED_PLAYLIST_ENTRIES,
     N_PROP
 };
@@ -259,7 +261,7 @@ parole_conf_class_init (ParoleConfClass *klass)
                                      PROP_SUBTITLE_FONT,
                                      g_param_spec_string  ("subtitle-font",
                                                            NULL, NULL,
-                                                           "Sans 12",
+                                                           "Sans Bold 20",
                                                            G_PARAM_READWRITE));
     
     g_object_class_install_property (object_class,
@@ -316,7 +318,7 @@ parole_conf_class_init (ParoleConfClass *klass)
                                      g_param_spec_enum ("aspect-ratio",
                                                         NULL, NULL,
 							GST_ENUM_TYPE_ASPECT_RATIO,
-							PAROLE_ASPECT_RATIO_NONE,
+							PAROLE_ASPECT_RATIO_AUTO,
                                                         G_PARAM_READWRITE));
 						       
     g_object_class_install_property (object_class,
@@ -347,6 +349,13 @@ parole_conf_class_init (ParoleConfClass *klass)
     /**
      *Playlist options
      **/
+    g_object_class_install_property (object_class,
+                                     PROP_SHOWHIDE_PLAYLIST,
+                                     g_param_spec_boolean ("showhide-playlist",
+                                                           NULL, NULL,
+                                                           FALSE,
+                                                           G_PARAM_READWRITE));
+
     g_object_class_install_property (object_class,
                                      PROP_REPLACE_PLAYLIST,
                                      g_param_spec_boolean ("replace-playlist",
@@ -368,6 +377,13 @@ parole_conf_class_init (ParoleConfClass *klass)
                                                            TRUE,
                                                            G_PARAM_READWRITE));
 
+    g_object_class_install_property (object_class,
+                                     PROP_REMEMBER_PLAYLIST,
+                                     g_param_spec_boolean ("remember-playlist",
+                                                           NULL, NULL,
+                                                           FALSE,
+                                                           G_PARAM_READWRITE));
+
     /**
      * 
      * Remove duplicated entries from the playlist.
@@ -396,7 +412,7 @@ parole_conf_load (ParoleConf *conf)
     
     if ( G_UNLIKELY (rc == NULL ) )
     {
-	g_warning ("Unable to lookup rc file in : %s\n", PAROLE_RESOURCE_FILE);
+	g_debug ("Unable to lookup rc file in : %s\n", PAROLE_RESOURCE_FILE);
 	return;
     }
 
