@@ -60,6 +60,12 @@ typedef struct
 								     
     void			(*uri_opened)			    (ParoleMediaList *list,
 								     const gchar *uri);
+								     
+	void			(*shuffle_toggled)		    (ParoleMediaList *list,
+								     gboolean shuffle_toggled);
+								     
+	void			(*repeat_toggled)		    (ParoleMediaList *list,
+								     gboolean repeat_toggled);
     
 } ParoleMediaListClass;
 
@@ -112,12 +118,18 @@ void				 parole_media_list_open		    (ParoleMediaList *list);
 void			         parole_media_list_open_location    (ParoleMediaList *list);
 
 gboolean			 parole_media_list_add_files        (ParoleMediaList *list,
-								     gchar **filenames);
+								     gchar **filenames, gboolean enqueue);
 
 void				 parole_media_list_save_list	    (ParoleMediaList *list);
 
 void				 parole_media_list_grab_focus       (ParoleMediaList *list);
 
+void				 parole_media_list_set_repeat_toggled		(ParoleMediaList *list,
+																gboolean repeat_toggled);
+																
+void 				 parole_media_list_set_shuffle_toggled		(ParoleMediaList *list,
+																gboolean shuffle_toggled);
+
 G_END_DECLS
 
 #endif /* __PAROLE_MEDIA_LIST_H */
